@@ -5,6 +5,7 @@
 import os
 from boto3.resources.factory import ServiceResource
 
+from baseblock import EnvIO
 from baseblock import FileIO
 from baseblock import Stopwatch
 from baseblock import BaseObject
@@ -42,18 +43,26 @@ class DownloadFromS3(BaseObject):
             craigtrim@gmail.com
             *   integrate s3-image-writer
                 https://github.com/craigtrim/awsfile-helper/issues/1
+        Updated:
+            1-Nov-2022
+            craigtrim@gmail.com
+            *   retrieve local directory from environment
+                https://github.com/craigtrim/awsfile-helper/issues/3
         """
         BaseObject.__init__(self, __name__)
+        self._local_directory = FileIO.local_directory_by_name(
+            EnvIO.str_or_default('LOCAL_DIRECTORY_NAME', 'AWSFileHelper'))
+
         self._read = S3BucketReader(s3).process
         self._download_image = S3ImageWriter(s3).process
         self._write_to_disk = FileContentWriter().process
 
-    @staticmethod
-    def _construct_local_path(file_path: str) -> str:
+    def _construct_local_path(self,
+                              file_path: str) -> str:
         if file_path:
             FileIO.exists_or_create(file_path)
             return file_path
-        return FileIO.local_directory_by_name('Graffl')
+        return self._local_directory
 
     def _process(self,
                  bucket_name: str,
